/*
 * Created on Oct 5, 2005
 *
 * TODO To change the template for this generated file go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
package frysk.gui.monitor.observers;

public class AttachedContinueObserver extends ObserverRoot{

	public AttachedContinueObserver() {
		super("AttachedContinueObserver", "Fires when a proc arrives at the AttachedContinue state");
	}
	
	public AttachedContinueObserver(AttachedContinueObserver other) {
		super(other);
	}

}
